@@ -1,7 +1,7 @@
 /*************************************************************************
  *   c_gsl_rng - C front ends for bits of GNU Scientific Library         *
  *                                                                       *
- *   Copyright (C) 2016 by Boud Roukema                                  *
+ *   Copyright (C) 2016-2017 by Boud Roukema                             *
  *   boud cosmo.torun.pl                                                 *
  *                                                                       *
  *   This program is free software; you can redistribute it and/or modify*
@@ -37,24 +37,22 @@
 */
 
 
-void get_gsl_rng_seeds(int nproc,
-                       long iseed,
-                       long MaxRandNumStreams,
-                       long *seeds /* 1D array [MaxRandNumStreams] */
+void get_gsl_rng_seeds(int64_t iseed,
+                       int32_t MaxRandNumStreams,
+                       int64_t *seeds /* 1D array [MaxRandNumStreams] */
                        );/* get_gsl_rng_ran_seeds */
 
 
 /* global random number generator - generate seeds, close generator */
-void get_gsl_rng_seeds(int nproc,
-                       long iseed,
-                       long MaxRandNumStreams,
-                       long *seeds /* 1D array [MaxRandNumStreams] */
+void get_gsl_rng_seeds(int64_t iseed,
+                       int32_t MaxRandNumStreams,
+                       int64_t *seeds /* 1D array [MaxRandNumStreams] */
                        )/* get_gsl_rng_ran_seeds */
 {
   const gsl_rng_type * T_gsl;
   gsl_rng * r_gsl;
 
-  long i_seeds;
+  int32_t i_seeds;
 
   /* MT19937 - Makoto Matsumoto and Takuji Nishimura;
      Mersenne prime period of 2^19937 - 1;
@@ -70,30 +68,31 @@ void get_gsl_rng_seeds(int nproc,
   */
   /* T_gsl = gsl_rng_ranlxd2; */
 
-  /* Fortran does not seem to include unsigned integers,
-     so we store iseed and seeds[...] as signed long integers,
+  /* Fortran does not include unsigned integers,
+     so we store iseed and seeds[...] as signed 64-bit integers,
      but convert them back and forth when giving them to or
      getting them from gsl_rng.
   */
 
+  /* No conversion from int64_t should be needed as of 2017. */
   gsl_rng_default_seed = (unsigned long) iseed;
   r_gsl = gsl_rng_alloc(T_gsl);
 
   for(i_seeds=0; i_seeds < MaxRandNumStreams; i_seeds++){
-    seeds[i_seeds] = (long) gsl_rng_get(r_gsl);
+    seeds[i_seeds] = (int64_t) gsl_rng_get(r_gsl);
   };
 
   gsl_rng_free(r_gsl);
 }
 
-void gauss_gsl(long Seed,
+void gauss_gsl(int64_t Seed,
                double *RandNum,
                int free_gauss_gsl);
 
 
 /* Independent instances of this are created
    by independent mpi threads. */
-void gauss_gsl(long Seed,
+void gauss_gsl(int64_t Seed,
                double *RandNum,
                int free_gauss_gsl){
 
